"use strict";
//  Copyright PrimeObjects Software Inc. and other contributors <https://www.primeobjects.com/>
// 
//  This source code is licensed under the MIT license.
//  The detail information can be found in the LICENSE file in the root directory of this source tree.
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeLocalStorage = exports.setLocalStorage = exports.getLocalStorage = void 0;
var core_1 = require("primeobjects-helper-util/build/cjs/core");
var lodash_1 = require("lodash");
var getLocalStorage = function (key, defaultValue) {
    if (!(0, core_1.isNonEmptyString)(key))
        return null;
    var data = null;
    var storageData = (0, core_1.getWindow)().localStorage.getItem(key);
    if ((0, lodash_1.isNil)(storageData))
        return defaultValue;
    if ((0, core_1.isNonEmptyString)(storageData)) {
        try {
            data = JSON.parse(storageData);
            if ((0, core_1.isObject)(data) && (0, lodash_1.isInteger)(data.ttl)) //ttl in seconds
             {
                if (Date.now() > data.ttl * 1000) {
                    (0, exports.removeLocalStorage)(key);
                    return !(0, lodash_1.isNil)(defaultValue) ? defaultValue : null;
                }
                else {
                    return data.data;
                }
            }
        }
        catch (_a) {
            data = storageData;
        }
    }
    else {
        data = storageData;
    }
    return !(0, lodash_1.isNil)(data) ? data : (!(0, lodash_1.isNil)(defaultValue) ? defaultValue : null);
};
exports.getLocalStorage = getLocalStorage;
var setLocalStorage = function (key, data, expireMinutes) {
    if (!(0, core_1.isNonEmptyString)(key))
        return null;
    if ((0, lodash_1.isNil)(data))
        return (0, core_1.getWindow)().localStorage.removeItem(key);
    if (expireMinutes && (0, lodash_1.isInteger)(expireMinutes) && expireMinutes > 0) {
        var storageData = { data: data, ttl: (0, core_1.ttl)(expireMinutes) };
        (0, core_1.getWindow)().localStorage.setItem(key, JSON.stringify(storageData));
    }
    else {
        (0, core_1.getWindow)().localStorage.setItem(key, (0, core_1.isObject)(data) ? JSON.stringify(data) : data);
    }
};
exports.setLocalStorage = setLocalStorage;
var removeLocalStorage = function (key) {
    localStorage.removeItem(key);
};
exports.removeLocalStorage = removeLocalStorage;
